@@ -624,9 +624,9 @@ void gcpApplication::OpenWithBabel (string const &filename, const gchar *mime_ty
 			g_free (old_num_locale);
 			g_free (buf);
 		}
-		if (!result)
-		{
-			if (bNew) delete pDoc;
+		if (!result) {
+			if (bNew)
+				pDoc->GetWindow ()->Destroy ();
 			throw (int) 2;
 		}
 		pDoc->SetFileName (filename, mime_type);
@@ -751,7 +751,7 @@ void gcpApplication::OpenGcp (string const &filename, gcpDocument* pDoc)
 		g_free(old_time_locale);
 		if (!result) {
 			if (create)
-				delete pDoc;
+				pDoc->GetWindow ()->Destroy ();
 			throw (int) 4;
 		}
 		if (!(info->permissions & (GNOME_VFS_PERM_USER_WRITE | GNOME_VFS_PERM_GROUP_WRITE)))
