@@ -723,7 +723,7 @@ bool gcpView::OnKeyPress(GtkWidget* w, GdkEventKey* event)
 			pActiveTool->OnKeyPressed (GDK_MOD1_MASK);//FIXME: might be not portable
 		return true;
 	default: {
-			if ((event->state & ~GDK_SHIFT_MASK) != 0 || event->keyval > 127)
+			if ((event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK)) != 0 || event->keyval > 127)
 				break;
 			// Now try to get the atom at the cursor
 			gcpAtom *atom = dynamic_cast<gcpAtom*> (m_CurObject);
